==> Hs6UG171.db_2.2.0.tar.gz: Hs6UG171.db/man/Hs6UG171_dbconn.Rd <==
\name{Hs6UG171_dbconn}

\alias{Hs6UG171_dbconn}
\alias{Hs6UG171_dbfile}
\alias{Hs6UG171_dbschema}
\alias{Hs6UG171_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Hs6UG171_dbconn()
  Hs6UG171_dbfile()
  Hs6UG171_dbschema(file="", show.indices=FALSE)
  Hs6UG171_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Hs6UG171_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{Hs6UG171_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{Hs6UG171_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Hs6UG171_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Hs6UG171_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Hs6UG171_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{Hs6UG171_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Hs6UG171_dbschema}: none (invisible \code{NULL}).

  \code{Hs6UG171_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Hs6UG171_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Hs6UG171_dbconn() was created with:
  dbConnect(SQLite(), dbname=Hs6UG171_dbfile(), cache_size=64000, synchronous=0)

  Hs6UG171_dbschema()

  Hs6UG171_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> Hs6UG171.db_2.3.5.tar.gz: Hs6UG171.db/man/Hs6UG171_dbconn.Rd <==

\name{Hs6UG171_dbconn}

\alias{Hs6UG171_dbconn}
\alias{Hs6UG171_dbfile}
\alias{Hs6UG171_dbschema}
\alias{Hs6UG171_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Hs6UG171_dbconn()
  Hs6UG171_dbfile()
  Hs6UG171_dbschema(file="", show.indices=FALSE)
  Hs6UG171_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Hs6UG171_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{Hs6UG171_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{Hs6UG171_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Hs6UG171_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Hs6UG171_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Hs6UG171_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{Hs6UG171_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Hs6UG171_dbschema}: none (invisible \code{NULL}).

  \code{Hs6UG171_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Hs6UG171_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Hs6UG171_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=Hs6UG171_dbfile(), cache_size=64000,
  synchronous=0)

  Hs6UG171_dbschema()

  Hs6UG171_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
